@@ -8,7 +8,7 @@ use aliased 'MooseX::Declare::Syntax::Keyword::Role',  'RoleKeyword';
 
 use namespace::clean;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub import {
     my ($class, %args) = @_;
@@ -19,7 +19,7 @@ sub import {
     warnings->import;
 
     for my $keyword ($class->keywords) {
-        $keyword->setup_for($caller, %args);
+        $keyword->setup_for($caller, %args, provided_by => $class);
     }
 }
 
