@@ -8,7 +8,7 @@ with 'MooseX::Declare::Syntax::MethodDeclaration';
 
 sub register_method_declaration {
     my ($self, $class, $method) = @_;
-    return $class->meta->add_method($method->name, $method->body);
+    return $class->meta->add_method($method->name, $method);
 }
 
 1;
